@@ -1,15 +1,18 @@
 package Data::Walk::Clone;
+BEGIN {
+  $Data::Walk::Clone::AUTHORITY = 'cpan:JANDREW';
+}
+use version; our $VERSION = qv("v0.26.6");
 use Moose::Role;
 requires 
 	'_process_the_data', 
 	'_dispatch_method', 
 	'_get_had_secondary';
-use MooseX::Types::Moose qw(	
-        HashRef
-        ArrayRef
-        Bool
-    );######<--------------------------------------------------------  ADD New types here
-use version; our $VERSION = qv('0.024.004');
+use	Types::Standard qw(
+		HashRef
+		is_HashRef
+		Bool
+	);
 if( $ENV{ Smart_Comments } ){
 	use Smart::Comments -ENV;
 	### Smart-Comments turned on for Data-Walk-Clone
